==> fred-frgal_2.2.0.orig.tar.gz: fred-frgal-2.2.0/frgal/tests/test_decoder.py <==
"""Tests for decoder module."""
from datetime import datetime
from unittest import TestCase

import pytz
from google.protobuf.timestamp_pb2 import Timestamp

from frgal.decoder import GrpcDecoder
from frgal.exceptions import DecoderError, FrgalException, UnknownError

from .proto.example_pb2 import (ComplexMessage, CompositeDictMessage, CompositeListMessage, DictMessage, ListMessage,
                                NestedMessage, Reply, SimpleMessage)


class TestGrpcDecoder(TestCase):
    """Test GrpcDecoder."""

    def setUp(self):
        self.decoder = GrpcDecoder()

    # Test various message structures
    def test_decode_empty_message(self):
        self.assertEqual(self.decoder.decode(SimpleMessage()), None)

    def test_decode_onefield_message(self):
        msg = SimpleMessage()
        msg.value = 'Arnold Rimmer'

        self.assertEqual(self.decoder.decode(msg), 'Arnold Rimmer')

    def test_decode_complex_message(self):
        msg = ComplexMessage()
        msg.value = 'Arnold Rimmer'
        msg.count = 42

        self.assertEqual(self.decoder.decode(msg), {'value': 'Arnold Rimmer', 'count': 42})

    def test_decode_nested_empty(self):
        msg = NestedMessage()

        self.assertEqual(self.decoder.decode(msg), None)

    def test_decode_nested(self):
        msg = NestedMessage()
        msg.value.value = 'Arnold'

        self.assertEqual(self.decoder.decode(msg), 'Arnold')

    def test_decode_with_primitive_type_default_values(self):
        self.assertEqual(self.decoder.decode(ComplexMessage()), {'value': None, 'count': 0})

    # Test various value types
    def test_decode_list_empty(self):
        msg = ListMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_list(self):
        msg = ListMessage()
        msg.values.append('Arnold')
        msg.values.append('Lister')

        self.assertEqual(self.decoder.decode(msg), ['Arnold', 'Lister'])

    def test_decode_composite_list_empty(self):
        msg = CompositeListMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_composite_list(self):
        msg = CompositeListMessage()
        arnold = SimpleMessage()
        arnold.value = 'Arnold'
        lister = SimpleMessage()
        lister.value = 'Lister'
        msg.values.MergeFrom([arnold, lister])

        self.assertEqual(self.decoder.decode(msg), ['Arnold', 'Lister'])

    def test_decode_dict_empty(self):
        msg = DictMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_dict(self):
        msg = DictMessage()
        msg.values['arnold'] = 'Arnold'
        msg.values['lister'] = 'Lister'

        self.assertEqual(self.decoder.decode(msg), {'arnold': 'Arnold', 'lister': 'Lister'})

    def test_decode_composite_dict_empty(self):
        msg = CompositeDictMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_composite_dict(self):
        msg = CompositeDictMessage()
        msg.values['arnold'].value = 'Arnold'
        msg.values['lister'].value = 'Lister'

        self.assertEqual(self.decoder.decode(msg), {'arnold': 'Arnold', 'lister': 'Lister'})

    def test_decode_unknown_type(self):
        with self.assertRaises(DecoderError):
            self.decoder.decode(object()),

    def test_decode_timestamp(self):
        self.assertEqual(
            self.decoder.decode(Timestamp(seconds=0, nanos=0)),
            datetime(1970, 1, 1, 0, 0, tzinfo=pytz.utc)
        )
        self.assertEqual(
            self.decoder.decode(Timestamp(seconds=123456789, nanos=12345678)),
            datetime(1973, 11, 29, 21, 33, 9, 12346, tzinfo=pytz.utc)
        )

    # Test exceptions
    def test_decode_exception(self):
        # Add exception decoder
        class TeaPotError(FrgalException):
            pass

        self.decoder.set_exception_decoder('tea_pot_error', TeaPotError)

        reply = Reply()
        reply.exception.tea_pot_error.CopyFrom(Reply.Exception.TeaPotError())
        self.assertIsInstance(self.decoder.decode_exception(reply.exception), TeaPotError)

    def test_decode_exception_unknown(self):
        error = Reply.Exception()
        self.assertIsInstance(self.decoder.decode_exception(error), UnknownError)

==> fred-frgal_3.3.1.orig.tar.gz: fred-frgal-3.3.1/frgal/tests/test_decoder.py <==
"""Tests for decoder module."""
from datetime import datetime
from unittest import TestCase

import pytz
from google.protobuf.empty_pb2 import Empty
from google.protobuf.struct_pb2 import Struct
from google.protobuf.timestamp_pb2 import Timestamp

from frgal.decoder import GrpcDecoder
from frgal.exceptions import DecoderError, FrgalException, UnknownError

from .proto.example_pb2 import (ComplexMessage, CompositeDictMessage, CompositeListMessage, DictMessage, ListMessage,
                                NestedMessage, Reply, SimpleMessage)


class TestGrpcDecoder(TestCase):
    """Test GrpcDecoder."""

    def setUp(self):
        self.decoder = GrpcDecoder()

    # Test various message structures
    def test_decode_empty(self):
        self.assertIsNone(self.decoder.decode(Empty()))

    def test_decode_empty_message(self):
        self.assertEqual(self.decoder.decode(SimpleMessage()), None)

    def test_decode_onefield_message(self):
        msg = SimpleMessage()
        msg.value = 'Arnold Rimmer'

        self.assertEqual(self.decoder.decode(msg), 'Arnold Rimmer')

    def test_decode_complex_message(self):
        msg = ComplexMessage()
        msg.value = 'Arnold Rimmer'
        msg.count = 42

        self.assertEqual(self.decoder.decode(msg), {'value': 'Arnold Rimmer', 'count': 42})

    def test_decode_nested_empty(self):
        msg = NestedMessage()

        self.assertEqual(self.decoder.decode(msg), None)

    def test_decode_nested(self):
        msg = NestedMessage()
        msg.value.value = 'Arnold'

        self.assertEqual(self.decoder.decode(msg), 'Arnold')

    def test_decode_with_primitive_type_default_values(self):
        self.assertEqual(self.decoder.decode(ComplexMessage()), {'value': None, 'count': 0})

    # Test various value types
    def test_decode_list_empty(self):
        msg = ListMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_list(self):
        msg = ListMessage()
        msg.values.append('Arnold')
        msg.values.append('Lister')

        self.assertEqual(self.decoder.decode(msg), ['Arnold', 'Lister'])

    def test_decode_composite_list_empty(self):
        msg = CompositeListMessage()
        self.assertEqual(self.decoder.decode(msg), [])

    def test_decode_composite_list(self):
        msg = CompositeListMessage()
        arnold = SimpleMessage()
        arnold.value = 'Arnold'
        lister = SimpleMessage()
        lister.value = 'Lister'
        msg.values.MergeFrom([arnold, lister])

        self.assertEqual(self.decoder.decode(msg), ['Arnold', 'Lister'])

    def test_decode_dict_empty(self):
        msg = DictMessage()
        self.assertEqual(self.decoder.decode(msg), {})

    def test_decode_dict(self):
        msg = DictMessage()
        msg.values['arnold'] = 'Arnold'
        msg.values['lister'] = 'Lister'

        self.assertEqual(self.decoder.decode(msg), {'arnold': 'Arnold', 'lister': 'Lister'})

    def test_decode_composite_dict_empty(self):
        msg = CompositeDictMessage()
        self.assertEqual(self.decoder.decode(msg), {})

    def test_decode_composite_dict(self):
        msg = CompositeDictMessage()
        msg.values['arnold'].value = 'Arnold'
        msg.values['lister'].value = 'Lister'

        self.assertEqual(self.decoder.decode(msg), {'arnold': 'Arnold', 'lister': 'Lister'})

    def test_decode_unknown_type(self):
        with self.assertRaises(DecoderError):
            self.decoder.decode(object()),

    def test_decode_timestamp(self):
        self.assertIsNone(self.decoder.decode(Timestamp()))

        self.assertEqual(
            self.decoder.decode(Timestamp(nanos=1)),
            datetime(1970, 1, 1, 0, 0, 0, 0, tzinfo=pytz.utc)
        )

        self.assertEqual(
            self.decoder.decode(Timestamp(seconds=1)),
            datetime(1970, 1, 1, 0, 0, 1, 0, tzinfo=pytz.utc)
        )

        self.assertEqual(
            self.decoder.decode(Timestamp(seconds=123456789, nanos=12345678)),
            datetime(1973, 11, 29, 21, 33, 9, 12345, tzinfo=pytz.utc)
        )

    def test_decode_oneof_empty(self):
        # Test decoding of empty oneof fields
        reply = Reply()

        self.assertEqual(self.decoder.decode(reply), {})

    def test_decode_oneof(self):
        # Test decoding of oneof fields
        reply = Reply()
        reply.data.result = 'Gazpacho!'

        self.assertEqual(self.decoder.decode(reply), {'data': 'Gazpacho!'})

    def test_decode_struct_simple(self):
        data = {'secret': 'Gazpacho!'}
        struct = Struct()
        struct.update(data)

        self.assertEqual(self.decoder.decode(struct), data)

    def test_decode_struct_nested(self):
        data = {'secret': 'Gazpacho!', 'context': {'person': 'Rimmer'}}
        struct = Struct()
        struct.update(data)

        self.assertEqual(self.decoder.decode(struct), data)

    def test_decode_struct_nested_list(self):
        data = {'secret': 'Gazpacho!', 'context': [42, 1, 17, -10]}
        struct = Struct()
        struct.update(data)

        self.assertEqual(self.decoder.decode(struct), data)

    def test_decode_struct_nested_nested_list(self):
        data = {'secret': 'Gazpacho!', 'context': [[42, 1], [17, -10]]}
        struct = Struct()
        struct.update(data)

        self.assertEqual(self.decoder.decode(struct), data)

    # Test exceptions
    def test_decode_exception(self):
        # Add exception decoder
        class TeaPotError(FrgalException):
            pass

        self.decoder.set_exception_decoder('tea_pot_error', TeaPotError)

        reply = Reply()
        reply.exception.tea_pot_error.CopyFrom(Reply.Exception.TeaPotError())
        self.assertIsInstance(self.decoder.decode_exception(reply.exception), TeaPotError)

    def test_decode_exception_unknown(self):
        error = Reply.Exception()
        self.assertIsInstance(self.decoder.decode_exception(error), UnknownError)
